@@ -3,7 +3,7 @@
 
 from tornado.gen import coroutine
 
-from holmes.models import Domain
+from holmes.models import Domain, KeysCategory
 from holmes.handlers import BaseHandler
 
 
@@ -130,6 +130,11 @@ class DomainReviewsHandler(BaseHandler):
             page_filter=term,
         )
 
+        if 'error' in reviews:
+            self.set_status(reviews['error']['status_code'], reviews['error']['reason'])
+            self.finish()
+            return
+
         if 'reviewsCount' not in reviews:
             if not term:
                 reviews['reviewsCount'] = yield self.cache.get_active_review_count(domain)
@@ -187,20 +192,22 @@ class DomainTopCategoryViolationsHandler(BaseHandler):
             self.set_status(404, self._('Domain %s not found') % domain_name)
             return
 
+        key_category = KeysCategory.get_by_id(self.db, key_category_id)
+
+        if not key_category:
+            self.set_status(404, self._('Key category %s not found') % key_category_id)
+            return
+
         violation_defs = self.application.violation_definitions
 
-        top_violations = yield self.cache.get_top_in_category_for_domain(
-            domain,
-            key_category_id,
-            self.application.config.get('TOP_CATEGORY_VIOLATIONS_LIMIT')
-        )
+        top_violations = self.girl.get('top_violations_in_category_for_domains')
 
         violations = []
-        for key_name, count in top_violations:
+        for top_violation in top_violations.get(domain_name, {}).get(key_category.id, []):
             violations.append({
-                'title': self._(violation_defs[key_name]['title']),
-                'count': count,
-                'key': key_name,
+                'title': self._(violation_defs[top_violation['key_name']]['title']),
+                'count': top_violation['count'],
+                'key': top_violation['key_name'],
             })
 
         result = {
