@@ -16,6 +16,7 @@ from sqlalchemy import func
 from sqlalchemy.orm import joinedload
 
 import logging
+import time
 
 
 class ElasticSearchProvider(SearchProvider):
@@ -107,20 +108,27 @@ class ElasticSearchProvider(SearchProvider):
         }
 
     def index_review(self, review):
-        self.syncES.send_request(
-            method='POST',
-            path_components=[self.index, 'review', review.page_id],
-            body=dumps(self.gen_doc(review)),
-            encode_body=False
-        )
+        for _ in range(3):
+            try:
+                self.syncES.send_request(
+                    method='POST',
+                    path_components=[self.index, 'review', review.page_id],
+                    body=dumps(self.gen_doc(review)),
+                    encode_body=False
+                )
+                break
+            except Exception as e:
+                values = review.id, review.page_id, str(e)
+                logging.error('Could not index review (review_id:{0}, page_id:{1}): {2}'.format(*values))
+                time.sleep(1)
 
-    def index_reviews(self, reviewd_pages, reviews_count, batch_size):
+    def index_reviews(self, reviewed_pages, reviews_count, batch_size):
         action = {'index': {'_type': 'review'}}
 
-        for i in xrange(0, reviews_count, batch_size):
+        for i in range(0, reviews_count, batch_size):
             body_bits = []
 
-            for page in reviewd_pages[i:i + batch_size]:
+            for page in reviewed_pages[i:i + batch_size]:
                 doc = self.gen_doc(page.last_review)
 
                 action['index']['_id'] = doc['page_id']
@@ -144,30 +152,36 @@ class ElasticSearchProvider(SearchProvider):
     def get_by_violation_key_name(self, key_id, current_page=1, page_size=10, domain=None, page_filter=None, callback=None):
         def treat_response(response):
             if response.error is None:
-                hits = loads(response.body).get('hits', {'hits': []})
+                try:
+                    hits = loads(response.body).get('hits', {'hits': []})
 
-                reviews_data = []
-                for hit in hits['hits']:
-                    completedAt = datetime.utcfromtimestamp(hit['_source']['completed_date'])
-                    reviews_data.append({
-                        'uuid': hit['_source']['uuid'],
-                        'page': {
-                            'uuid': hit['_source']['page_uuid'],
-                            'url': hit['_source']['page_url'],
-                            'completedAt': completedAt
-                        },
-                        'domain': hit['_source']['domain_name']
+                    reviews_data = []
+                    for hit in hits['hits']:
+                        completedAt = datetime.utcfromtimestamp(hit['_source']['completed_date'])
+                        reviews_data.append({
+                            'uuid': hit['_source']['uuid'],
+                            'page': {
+                                'uuid': hit['_source']['page_uuid'],
+                                'url': hit['_source']['page_url'],
+                                'completedAt': completedAt
+                            },
+                            'domain': hit['_source']['domain_name']
+                        })
+
+                    reviews_count = hits.get('total', 0)
+
+                    callback({
+                        'reviews': reviews_data,
+                        'reviewsCount': reviews_count
                     })
-
-                reviews_count = hits.get('total', 0)
-
-                callback({
-                    'reviews': reviews_data,
-                    'reviewsCount': reviews_count
-                })
+                except Exception as e:
+                    reason = 'ElasticSearchProvider: invalid response (%s [%s])' % (type(e), e.message)
+                    logging.error(reason)
+                    callback({'error': {'status_code': 500, 'reason': reason}})
             else:
-                logging.error('ElasticSearchProvider error: %s (%s)' % (response.error.message, response.body))
-                raise response.error
+                reason = 'ElasticSearchProvider: erroneous response (%s [%s])' % (response.error.message, response.body)
+                logging.error(reason)
+                callback({'error': {'status_code': 500, 'reason': reason}})
 
         inner_query = self._assemble_inner_query(domain, page_filter)
         filter_terms = self._assemble_filter_terms(key_id, domain)
@@ -199,28 +213,34 @@ class ElasticSearchProvider(SearchProvider):
     def get_domain_active_reviews(self, domain, current_page=1, page_size=10, page_filter=None, callback=None):
         def treat_response(response):
             if response.error is None:
-                hits = loads(response.body).get('hits', {'hits': []})
+                try:
+                    hits = loads(response.body).get('hits', {'hits': []})
 
-                pages = []
-                for hit in hits['hits']:
-                    completedAt = datetime.utcfromtimestamp(hit['_source']['completed_date'])
-                    pages.append({
-                        'url': hit['_source']['page_url'],
-                        'uuid': hit['_source']['page_uuid'],
-                        'violationCount': len(hit['_source']['keys']),
-                        'completedAt': completedAt,
-                        'reviewId': hit['_source']['uuid']
+                    pages = []
+                    for hit in hits['hits']:
+                        completedAt = datetime.utcfromtimestamp(hit['_source']['completed_date'])
+                        pages.append({
+                            'url': hit['_source']['page_url'],
+                            'uuid': hit['_source']['page_uuid'],
+                            'violationCount': len(hit['_source']['keys']),
+                            'completedAt': completedAt,
+                            'reviewId': hit['_source']['uuid']
+                        })
+
+                    reviews_count = hits.get('total', 0)
+
+                    callback({
+                        'reviewsCount': reviews_count,
+                        'pages': pages
                     })
-
-                reviews_count = hits.get('total', 0)
-
-                callback({
-                    'reviewsCount': reviews_count,
-                    'pages': pages
-                })
+                except Exception as e:
+                    reason = 'ElasticSearchProvider: invalid response (%s [%s])' % (type(e), e.message)
+                    logging.error(reason)
+                    callback({'error': {'status_code': 500, 'reason': reason}})
             else:
-                logging.error('ElasticSearchProvider error: %s' % response.error.message)
-                raise response.error
+                reason = 'ElasticSearchProvider: erroneous response (%s [%s])' % (response.error.message, response.body)
+                logging.error(reason)
+                callback({'error': {'status_code': 500, 'reason': reason}})
 
         inner_query = self._assemble_inner_query(domain=domain, page_filter=page_filter)
         filter_terms = self._assemble_filter_terms(domain=domain)
@@ -249,7 +269,10 @@ class ElasticSearchProvider(SearchProvider):
         )
 
     def refresh(self):
-        self.syncES.refresh(index=self.index)
+        try:
+            self.syncES.refresh(index=self.index)
+        except Exception as e:
+            logging.error('Could not refresh index (%s)' % e)
 
     def get_index_settings(cls):
         return {
@@ -311,14 +334,14 @@ class ElasticSearchProvider(SearchProvider):
             mapping = self.get_index_mapping()
             self.syncES.put_mapping(index=self.index, doc_type='review', mapping=mapping)
             logging.info('Index %s created.' % self.index)
-        except Exception, e:
+        except Exception as e:
             raise e
 
     def delete_index(self):
         try:
             self.syncES.delete_index(index=self.index)
             logging.info('Index %s deleted.' % self.index)
-        except Exception, e:
+        except Exception as e:
             raise e
 
     def _get_max_page_id_from_index(self, must_have_domain_name=False):
@@ -380,11 +403,11 @@ class ElasticSearchProvider(SearchProvider):
         reviews_count = apply_filters(self.db.query(func.count(Page))).scalar()
 
         query = self.db.query(Page).options(joinedload('last_review'))
-        reviewd_pages = apply_filters(query).order_by(Page.id.asc())
+        reviewed_pages = apply_filters(query).order_by(Page.id.asc())
 
         logging.info('Indexing %d reviews...' % reviews_count)
 
-        self.index_reviews(reviewd_pages, reviews_count, batch_size)
+        self.index_reviews(reviewed_pages, reviews_count, batch_size)
 
     @classmethod
     def new_instance(cls, config):
@@ -457,7 +480,7 @@ class ElasticSearchProvider(SearchProvider):
                             es.delete_index()
                         except ElasticHttpNotFoundError:
                             pass
-                        except InvalidJsonResponseError, e:
+                        except InvalidJsonResponseError as e:
                             logging.error('Invalid response! Reason: %s' % e)
                             sys.exit(1)
                     if args.create or args.recreate:
@@ -476,7 +499,7 @@ class ElasticSearchProvider(SearchProvider):
                             es.index_all_reviews(args.keys, replace=args.replace, batch_size=batch_size)
                         elif args.all_keys:
                             es.index_all_reviews(replace=args.replace, batch_size=batch_size)
-                    except InvalidJsonResponseError, e:
+                    except InvalidJsonResponseError as e:
                         logging.error('Invalid response! Reason: %s' % e)
                         sys.exit(1)
 
